@@ -68,8 +68,7 @@ class AdHocClient(aioxmpp.service.Service):
 
     ORDER_AFTER = [aioxmpp.disco.DiscoClient]
 
-    @asyncio.coroutine
-    def get_commands(self, peer_jid):
+    async def get_commands(self, peer_jid):
         """
         Return the list of commands offered by the peer.
 
@@ -85,14 +84,13 @@ class AdHocClient(aioxmpp.service.Service):
         """
 
         disco = self.dependencies[aioxmpp.disco.DiscoClient]
-        response = yield from disco.query_items(
+        response = await disco.query_items(
             peer_jid,
             node=namespaces.xep0050_commands,
         )
         return response.items
 
-    @asyncio.coroutine
-    def get_command_info(self, peer_jid, command_name):
+    async def get_command_info(self, peer_jid, command_name):
         """
         Obtain information about a command.
 
@@ -115,14 +113,13 @@ class AdHocClient(aioxmpp.service.Service):
         """
 
         disco = self.dependencies[aioxmpp.disco.DiscoClient]
-        response = yield from disco.query_info(
+        response = await disco.query_info(
             peer_jid,
             node=command_name,
         )
         return response
 
-    @asyncio.coroutine
-    def supports_commands(self, peer_jid):
+    async def supports_commands(self, peer_jid):
         """
         Detect whether a peer supports :xep:`50` Ad-Hoc commands.
 
@@ -137,14 +134,13 @@ class AdHocClient(aioxmpp.service.Service):
         """
 
         disco = self.dependencies[aioxmpp.disco.DiscoClient]
-        response = yield from disco.query_info(
+        response = await disco.query_info(
             peer_jid,
         )
 
         return namespaces.xep0050_commands in response.features
 
-    @asyncio.coroutine
-    def execute(self, peer_jid, command_name):
+    async def execute(self, peer_jid, command_name):
         """
         Start execution of a command with a peer.
 
@@ -167,7 +163,7 @@ class AdHocClient(aioxmpp.service.Service):
             peer_jid,
             command_name,
         )
-        yield from session.start()
+        await session.start()
         return session
 
 
@@ -257,8 +253,7 @@ class AdHocServer(aioxmpp.service.Service, aioxmpp.disco.Node):
 
     @aioxmpp.service.iq_handler(aioxmpp.IQType.SET,
                                 adhoc_xso.Command)
-    @asyncio.coroutine
-    def _handle_command(self, stanza):
+    async def _handle_command(self, stanza):
         try:
             info = self._commands[stanza.payload.node]
         except KeyError:
@@ -274,7 +269,7 @@ class AdHocServer(aioxmpp.service.Service, aioxmpp.disco.Node):
                 aioxmpp.errors.ErrorCondition.FORBIDDEN,
             )
 
-        return (yield from info.handler(stanza))
+        return await info.handler(stanza)
 
     def iter_items(self, stanza):
         local_jid = self.client.local_jid
@@ -296,52 +291,6 @@ class AdHocServer(aioxmpp.service.Service, aioxmpp.disco.Node):
                 node=node,
             )
 
-    # def register_stateful_command(self, node, name, handler, *,
-    #                               is_allowed=None,
-    #                               features={namespaces.xep0004_data}):
-    #     """
-    #     Register a handler for a stateful command.
-
-    #     :param node: Name of the command (``node`` in the service discovery
-    #                  list).
-    #     :type node: :class:`str`
-    #     :param name: Human-readable name of the command
-    #     :type name: :class:`str` or :class:`~.LanguageMap`
-    #     :param handler: Coroutine function to spawn when a new session is
-    #                     started.
-    #     :param is_allowed: A predicate which determines whether the command is
-    #                        shown and allowed for a given peer.
-    #     :type is_allowed: function or :data:`None`
-    #     :param features: Set of features to announce for the command
-    #     :type features: :class:`set` of :class:`str`
-
-    #     Whenever a new session is started, `handler` is invoked with a session
-    #     object which allows the handler to communicate with the client. The
-    #     details of the session are described at :class:`ServerSession`.
-
-    #     If `is_allowed` is not :data:`None`, it is invoked whenever a command
-    #     listing is generated and whenever a command session is about to start.
-    #     The :class:`~aioxmpp.JID` of the requester is passed as positional
-    #     argument to `is_allowed`. If `is_allowed` returns false, the command
-    #     is not included in the list and attempts to execute it are rejected
-    #     with ``<forbidden/>`` without calling `handler`.
-
-    #     If `is_allowed` is :data:`None`, the command is always visible and
-    #     allowed.
-
-    #     The `features` are returned on a service discovery info request for the
-    #     command node. By default, the :xep:`4` (Data Forms) namespace is
-    #     included, but this can be overridden by passing a different set without
-    #     that feature to `features`.
-
-    #     .. warning::
-
-    #        There is currently no rate-limiting mechanism implemented. It is
-    #        trivial for an attacker to exhaust memory by starting a huge amount
-    #        of sessions.
-
-    #     """
-
     def register_stateless_command(self, node, name, handler, *,
                                    is_allowed=None,
                                    features={namespaces.xep0004_data}):
@@ -522,8 +471,7 @@ class ClientSession:
         return {adhoc_xso.ActionType.EXECUTE,
                 adhoc_xso.ActionType.CANCEL}
 
-    @asyncio.coroutine
-    def start(self):
+    async def start(self):
         """
         Initiate the session by starting to execute the command with the peer.
 
@@ -545,16 +493,15 @@ class ClientSession:
             payload=adhoc_xso.Command(self._command_name),
         )
 
-        self._response = yield from self._stream.send_iq_and_wait_for_reply(
+        self._response = await self._stream.send_iq_and_wait_for_reply(
             request,
         )
 
         return self._response.first_payload
 
-    @asyncio.coroutine
-    def proceed(self, *,
-                action=adhoc_xso.ActionType.EXECUTE,
-                payload=None):
+    async def proceed(self, *,
+                      action=adhoc_xso.ActionType.EXECUTE,
+                      payload=None):
         """
         Proceed command execution to the next stage.
 
@@ -600,25 +547,23 @@ class ClientSession:
         )
 
         try:
-            self._response = \
-                yield from self._stream.send_iq_and_wait_for_reply(
-                    request,
-                )
+            self._response = await self._stream.send_iq_and_wait_for_reply(
+                request,
+            )
         except (aioxmpp.errors.XMPPModifyError,
                 aioxmpp.errors.XMPPCancelError) as exc:
             if isinstance(exc.application_defined_condition,
                           (adhoc_xso.BadSessionID,
                            adhoc_xso.SessionExpired)):
-                yield from self.close()
+                await self.close()
                 raise SessionError(exc.text)
             if isinstance(exc, aioxmpp.errors.XMPPCancelError):
-                yield from self.close()
+                await self.close()
             raise
 
         return self._response.first_payload
 
-    @asyncio.coroutine
-    def close(self):
+    async def close(self):
         if self._response is None:
             return
 
@@ -634,7 +579,7 @@ class ClientSession:
             )
 
             try:
-                yield from self._stream.send_iq_and_wait_for_reply(
+                await self._stream.send_iq_and_wait_for_reply(
                     request,
                 )
             except aioxmpp.errors.StanzaError as exc:
@@ -647,118 +592,10 @@ class ClientSession:
 
         self._response = None
 
-    @asyncio.coroutine
-    def __aenter__(self):
+    async def __aenter__(self):
         if self._response is None:
-            yield from self.start()
+            await self.start()
         return self
 
-    @asyncio.coroutine
-    def __aexit__(self, exc_type, exc_value, exc_traceback):
-        yield from self.close()
-
-
-# class ServerSession:
-#     """
-#     Represent an Ad-Hoc Commands session on the server side.
-
-#     :param stream: The stanza stream to communicate over
-#     :type stream: :class:`~.stream.StanzaStream`
-#     :param sessionid: Session ID to use for communication
-#     :type sessionid: :class:`str` or :data:`None`
-#     :param timeout: Maximum time to wait for a follow-up from the peer
-#     :type timeout: :class:`datetime.timedelta`
-
-#     The session knows its session ID and the peer JID and keeps track of client
-#     timeouts as well as the most recent reply.
-
-#     If `sessionid` is :data:`None`, a random session ID with at least 64 bits
-#     of entropy is generated.
-#     """
-
-#     def __init__(self, stream,
-#                  sessionid=None,
-#                  timeout=timedelta(seconds=60)):
-#         super().__init__()
-#         self.stream = stream
-#         self.peer_jid = peer_jid
-#         if sessionid is None:
-#             sessionid = base64.urlsafe_b64encode(
-#                 _rng.getrandbits(64).to_bytes(
-#                     64//8,
-#                     "little"
-#                 )
-#             ).rstrip(b"=").decode("ascii")
-#         self.sessionid = sessionid
-#         self.timeout = timeout
-#         self._future = None
-
-#     @asyncio.coroutine
-#     def handle(self, stanza):
-#         pass
-
-#     @asyncio.coroutine
-#     def reply(self, payload, status,
-#               *,
-#               actions={adhoc_xso.ActionType.NEXT,
-#                        adhoc_xso.ActionType.COMPLETE},
-#               default_action=adhoc_xso.ActionType.NEXT):
-#         """
-#         Send a reply to the peer.
-
-#         :param payload: Payload to send in the reply.
-#         :type payload: :class:`~.XSO` or sequence of :class:`~.XSO`
-#         :param status: Status of the command execution.
-#         :type status: :class:`~.adhoc.CommandStatus`
-#         :param actions: Set of actions allowed now.
-#         :type actions: set of :class:`~.adhoc.xso.ActionType`
-#         :param default_action: The action to assume if the client simply
-#                                continues with
-#                                :attr:`~.adhoc.xso.ActionType.EXECUTE`.
-#         :type default_action: :class:`~.adhoc.xso.ActionType` member which is
-#                               not :attr:`~.adhoc.xso.ActionType.EXECUTE`
-#         :raise ClientCancelledError: if the client cancels the execution
-#         :raise RuntimeError: if the client has not yet sent a request
-#         :raise TimeoutError: if the client does not send a follow-up message in
-#                              time
-#         :return: The chosen action and the payload given by the peer.
-#         :rtype: Pair of :class:`~.adhoc.xso.ActionType` and sequence of
-#                 :class:`~.XSO` objects.
-
-#         Send a reply to the peer. The `payload` must be a single
-#         :class:`~.XSO` or a sequence of :class:`~.XSO` objects. A single
-#         :class:`~.XSO` is wrapped in a sequence. The sequence is used as
-#         payload for the Ad-Hoc Command response.
-
-#         `status` informs the client about the current status of execution. For
-#         all but the last reply, this should be
-#         :attr:`~.adhoc.CommandStatus.EXECUTING`, but it should be set to
-#         :attr:`~.adhoc.CommandStatus.COMPLETED` on the last reply.
-#         Unfortunately, we do not have a sensible way to infer this, which is
-#         why there is no default for this argument.
-
-#         `actions` is the set of actions allowed for the client. The default is
-#         to allow the :attr:`~.adhoc.xso.ActionType.NEXT` and
-#         :attr:`~.adhoc.xso.ActionType.COMPLETE` actions. Depending on your
-#         application, you may need a different set of actions. You do not need
-#         to specify the :attr:`~.adhoc.xso.ActionType.EXECUTE` or
-#         :attr:`~.adhoc.xso.ActionType.CANCEL` action types, which are
-#         implicitly allowed.
-
-#         `default_action` is the action which is assumed when the client simply
-#         specifies the :attr:`~.adhoc.xso.ActionType.EXECUTE` action. It
-#         defaults to :attr:`~.adhoc.xso.ActionType.NEXT` and *must* be included
-#         in the `actions` set.
-
-#         The response from the client is generally returned a as a tuple
-#         consisting of the action chosen by the client and the payload sent by
-#         the client.
-
-#         If the client chooses the :attr:`~.adhoc.xso.ActionType.CANCEL` action,
-#         a :class:`RuntimeError` exception is raised and a confirmation of
-#         cancellation is sent to the client automatically and the session is
-#         closed.
-
-#         If the client does not answer within the timeout, :class:`TimeoutError`
-#         is raised and the session is closed.
-#         """
+    async def __aexit__(self, exc_type, exc_value, exc_traceback):
+        await self.close()
