@@ -182,14 +182,14 @@ class FutureListener:
     def data(self, data):
         try:
             self.fut.set_result(data)
-        except asyncio.futures.InvalidStateError:
+        except asyncio.InvalidStateError:
             pass
         return True
 
     def error(self, exc):
         try:
             self.fut.set_exception(exc)
-        except asyncio.futures.InvalidStateError:
+        except asyncio.InvalidStateError:
             pass
         return True
 
@@ -339,8 +339,8 @@ class AdHocSignal(AbstractAdHocSignal):
        using this mode.
 
        This mode can only be used for signals which send at most one
-       argument. If no argument is sent, the :meth:`~asyncio.Future.set_result`
-       method is called with :data:`None`.
+       positional argument. If no argument is sent, the
+       :meth:`~asyncio.Future.set_result` method is called with :data:`None`.
 
        If one argument is sent and it is an instance of :class:`Exception`, it
        is passed to :meth:`~asyncio.Future.set_exception`. Otherwise, if one
@@ -412,8 +412,6 @@ class AdHocSignal(AbstractAdHocSignal):
     @classmethod
     def AUTO_FUTURE(cls, f):
         def future_wrapper(args, kwargs):
-            if kwargs:
-                raise TypeError("keyword arguments not supported")
             if len(args) > 0:
                 try:
                     arg, = args
@@ -542,7 +540,7 @@ class AdHocSignal(AbstractAdHocSignal):
 
     def future(self):
         """
-        Return a :class:`asyncio.Future` which has been :meth:`connect`\ -ed
+        Return a :class:`asyncio.Future` which has been :meth:`connect`\\ -ed
         using :attr:`AUTO_FUTURE`.
 
         The token returned by :meth:`connect` is not returned; to remove the
@@ -601,8 +599,7 @@ class SyncAdHocSignal(AbstractAdHocSignal):
         """
         return SignalConnectionContext(self, coro)
 
-    @asyncio.coroutine
-    def fire(self, *args, **kwargs):
+    async def fire(self, *args, **kwargs):
         """
         Emit the signal, calling all coroutines in-line with the given
         arguments and in the order they were registered.
@@ -613,7 +610,7 @@ class SyncAdHocSignal(AbstractAdHocSignal):
         itself can be called, too.
         """
         for token, coro in list(self._connections.items()):
-            keep = yield from coro(*args, **kwargs)
+            keep = await coro(*args, **kwargs)
             if not keep:
                 del self._connections[token]
 
