@@ -492,7 +492,7 @@ class Room(aioxmpp.im.conversation.AbstractConversation):
 
     .. signal:: on_message(msg, member, source, **kwargs)
 
-        A message occured in the conversation.
+        A message occurred in the conversation.
 
         :param msg: Message which was received.
         :type msg: :class:`aioxmpp.Message`
@@ -598,7 +598,7 @@ class Room(aioxmpp.im.conversation.AbstractConversation):
         :type muc_nick: :class:`str`
 
         The `member` is matched by nickname. It is possible that the member is
-        not in the room at the time the topic chagne is received (for example
+        not in the room at the time the topic change is received (for example
         on a join).
 
         `muc_nick` is always the nickname of the entity who changed the topic.
@@ -1288,8 +1288,7 @@ class Room(aioxmpp.im.conversation.AbstractConversation):
                     reason,
                 )
             )
-        elif (existing.presence_state != info.presence_state or
-                existing.presence_status != info.presence_status):
+        else:
             to_emit.append((self.on_presence_changed,
                             (existing, None, stanza),
                             {}))
@@ -1884,10 +1883,12 @@ class MUCClient(aioxmpp.im.conversation.AbstractConversationService,
 
     .. automethod:: get_room_config
 
-    .. automethod:: set_affiliation
-
     .. automethod:: set_room_config
 
+    .. automethod:: get_affiliated
+
+    .. automethod:: set_affiliation
+
     Global events:
 
     .. signal:: on_muc_invitation(stanza, muc_address, inviter_address, mode, *, password=None, reason=None, **kwargs)
@@ -2364,6 +2365,35 @@ class MUCClient(aioxmpp.im.conversation.AbstractConversationService,
 
         return room, fut
 
+    async def get_affiliated(self, mucjid, affiliation):
+        """
+        Retrieve the list of JIDs with the given affiliation with a MUC.
+
+        :param mucjid: The bare JID identifying the MUC.
+        :type mucjid: :class:`~aioxmpp.JID`
+        :param affiliation: The affiliation level to query.
+        :type affiliation: :class:`str`
+        :raises: :class:`aioxmpp.errors.XMPPAuthError` if the client does not
+            have sufficient privileges to query affiliations of the given
+            level.
+        :return: Collection of JIDs with the given affiliation.
+        """
+        req = aioxmpp.stanza.IQ(
+            type_=aioxmpp.structs.IQType.GET,
+            to=mucjid,
+        )
+        req.payload = muc_xso.AdminQuery(
+            items=[
+                muc_xso.AdminItem(affiliation=affiliation),
+            ]
+        )
+
+        resp = await self.client.send(req)
+        return [
+            item.jid
+            for item in resp.items
+        ]
+
     async def set_affiliation(self, mucjid, jid, affiliation, *, reason=None):
         """
         Change the affiliation of an entity with a MUC.
