@@ -11,6 +11,9 @@
 -- The only thing left to do is rename this file to remove the .dist ending, and fill in the
 -- blanks. Good luck, and happy Jabbering!
 
+plugin_paths = {
+  "/etc/prosody/plugins"
+}
 
 ---------- Server-wide settings ----------
 -- Settings in this section apply to the whole server and are the default settings
@@ -150,6 +153,9 @@ log = {
 
 VirtualHost "localhost"
 Component "muc.localhost" "muc"
+modules_enabled = {
+	"muc_mam";
+}
 Component "pubsub.localhost" "pubsub"
 default_unowned_affiliation = "owner"
 Component "upload.localhost" "http_upload"
