@@ -22,7 +22,7 @@
 import asyncio
 
 from sphinx import addnodes
-from sphinx.domains.python import PyModulelevel, PyClassmember
+from sphinx.domains.python import PyModule, PyMethod
 
 from docutils import nodes, utils
 from docutils.parsers.rst import roles
@@ -42,61 +42,6 @@ from sphinx.util.nodes import (
 )
 
 
-class PyCoroutineMixin(object):
-    def handle_signature(self, sig, signode):
-        ret = super(PyCoroutineMixin, self).handle_signature(sig, signode)
-        signode.insert(0, addnodes.desc_annotation('coroutine ', 'coroutine '))
-        return ret
-
-
-class PyCoroutineFunction(PyCoroutineMixin, PyModulelevel):
-    def run(self):
-        self.name = 'py:function'
-        return PyModulelevel.run(self)
-
-
-class PyCoroutineMethod(PyCoroutineMixin, PyClassmember):
-    def run(self):
-        self.name = 'py:method'
-        return PyClassmember.run(self)
-
-
-class CoroutineAwareFunctionDocumenter(FunctionDocumenter):
-    objtype = 'function'
-    priority = 3
-
-    def import_object(self):
-        ret = ModuleLevelDocumenter.import_object(self)
-        if not ret:
-            return ret
-
-        if asyncio.iscoroutinefunction(self.object):
-            self.directivetype = "coroutinefunction"
-
-        return ret
-
-
-class DecoratorDocumenter(FunctionDocumenter):
-    objtype = 'decorator'
-    priority = 3
-
-
-class CoroutineAwareMethodDocumenter(MethodDocumenter):
-    objtype = 'method'
-    priority = 4
-
-    def import_object(self):
-        ret = super().import_object()
-        if not ret:
-            return ret
-
-        if     (self.directivetype == "method" and
-                asyncio.iscoroutinefunction(self.object)):
-            self.directivetype = "coroutinemethod"
-
-        return ret
-
-
 class SignalAwareMethodDocumenter(MethodDocumenter):
     objtype = 'signal'
     priority = 4
@@ -111,26 +56,26 @@ class SignalAwareMethodDocumenter(MethodDocumenter):
         return ret
 
 
-class PySignal(PyClassmember):
+class PySignal(PyMethod):
     def handle_signature(self, sig, signode):
-        ret = super(PySignal, self).handle_signature(sig, signode)
+        ret = super().handle_signature(sig, signode)
         signode.insert(0, addnodes.desc_annotation('signal ', 'signal '))
         return ret
 
     def run(self):
         self.name = 'py:method'
-        return PyClassmember.run(self)
+        return super().run()
 
 
-class PySyncSignal(PyClassmember):
+class PySyncSignal(PyMethod):
     def handle_signature(self, sig, signode):
-        ret = super(PySyncSignal, self).handle_signature(sig, signode)
-        signode.insert(0, addnodes.desc_annotation('coroutine signal ', 'coroutine signal '))
+        ret = super().handle_signature(sig, signode)
+        signode.insert(0, addnodes.desc_annotation('async signal ', 'async signal '))
         return ret
 
     def run(self):
         self.name = 'py:method'
-        return PyClassmember.run(self)
+        return super().run()
 
 
 def xep_role(typ, rawtext, text, lineno, inliner,
@@ -178,12 +123,7 @@ default_settings["xep_base_url"] = "https://xmpp.org/extensions/"
 
 
 def setup(app):
-    app.add_directive_to_domain('py', 'coroutinefunction', PyCoroutineFunction)
-    app.add_directive_to_domain('py', 'coroutinemethod', PyCoroutineMethod)
     app.add_directive_to_domain('py', 'signal', PySignal)
     app.add_directive_to_domain('py', 'syncsignal', PySyncSignal)
-    app.add_autodocumenter(CoroutineAwareFunctionDocumenter)
-    app.add_autodocumenter(CoroutineAwareMethodDocumenter)
     app.add_autodocumenter(SignalAwareMethodDocumenter)
-    app.add_autodocumenter(DecoratorDocumenter)
     return {'version': '1.0', 'parallel_read_safe': True}
